@@ -83,6 +83,11 @@ It supports various compressed files(gzip, bzip2, zstd, lz4, and xz).
 			config.General.ColumnDelimiter = "\t"
 		}
 
+		// SectionHeader is enabled if SectionHeaderNum is greater than 0.
+		if config.General.SectionHeaderNum > 0 {
+			config.General.SectionHeader = true
+		}
+
 		// Set a global variable to convert to a style before opening the file.
 		oviewer.OverStrikeStyle = oviewer.ToTcellStyle(config.StyleOverStrike)
 		oviewer.OverLineStyle = oviewer.ToTcellStyle(config.StyleOverLine)
@@ -365,6 +370,9 @@ func init() {
 	rootCmd.PersistentFlags().BoolP("section-header", "", false, "enable section-delimiter line as Header")
 	_ = viper.BindPFlag("general.SectionHeader", rootCmd.PersistentFlags().Lookup("section-header"))
 
+	rootCmd.PersistentFlags().IntP("section-header-num", "", 1, "number of header lines")
+	_ = viper.BindPFlag("general.SectionHeaderNum", rootCmd.PersistentFlags().Lookup("section-header-num"))
+
 	rootCmd.PersistentFlags().BoolP("follow-mode", "f", false, "follow mode")
 	_ = viper.BindPFlag("general.FollowMode", rootCmd.PersistentFlags().Lookup("follow-mode"))
 
@@ -386,6 +394,9 @@ func init() {
 	rootCmd.PersistentFlags().StringP("jump-target", "j", "", "jump target `[int|int%|.int|'section']`")
 	_ = viper.BindPFlag("general.JumpTarget", rootCmd.PersistentFlags().Lookup("jump-target"))
 
+	rootCmd.PersistentFlags().StringP("hscroll-width", "", "10%", "width to scroll horizontally `[int|int%|.int]`")
+	_ = viper.BindPFlag("general.HScrollWidth", rootCmd.PersistentFlags().Lookup("hscroll-width"))
+
 	// Config
 	rootCmd.PersistentFlags().BoolP("disable-mouse", "", false, "disable mouse support")
 	_ = viper.BindPFlag("DisableMouse", rootCmd.PersistentFlags().Lookup("disable-mouse"))
@@ -473,8 +484,9 @@ func initConfig() {
 
 	// If a config file is found, read it in.
 	if err := viper.ReadInConfig(); err != nil {
-		if _, ok := err.(viper.ConfigFileNotFoundError); !ok {
-			fmt.Fprintln(os.Stderr, err)
+		var configNotFoundError *viper.ConfigFileNotFoundError
+		if !errors.As(err, &configNotFoundError) {
+			fmt.Fprintln(os.Stderr, "failed to read config file:", err)
 			return
 		}
 	}
