@@ -160,10 +160,7 @@ func (root *Root) watchControl() {
 				m.tickerDone <- struct{}{}
 				return
 			case <-m.ticker.C:
-				ev := &eventReload{}
-				ev.SetEventNow()
-				ev.m = m
-				root.postEvent(ev)
+				root.sendReload(m)
 			}
 		}
 	}()
@@ -194,7 +191,7 @@ func (root *Root) goLine(input string) {
 	if len(input) == 0 {
 		return
 	}
-	num := docPosition(root.Doc.BufEndNum(), input)
+	num := calculatePosition(root.Doc.BufEndNum(), input)
 	str := strconv.FormatFloat(num, 'f', 1, 64)
 	if strings.HasSuffix(str, ".0") {
 		// Line number only.
@@ -324,6 +321,24 @@ func (root *Root) setSkipLines(input string) {
 	root.setMessagef("Set skip lines %d", num)
 }
 
+func (root *Root) setSectionNum(input string) {
+	num, err := strconv.Atoi(input)
+	if err != nil {
+		root.setMessagef("Set section header num: %s", ErrInvalidNumber.Error())
+		return
+	}
+	if num < 0 {
+		root.setMessagef("Set section header num: %s", ErrOutOfRange.Error())
+		return
+	}
+	if root.Doc.SectionHeaderNum == num {
+		return
+	}
+
+	root.Doc.SectionHeaderNum = num
+	root.setMessagef("Set section header num %d", num)
+}
+
 // suspend suspends the current screen display and runs the shell.
 // It will return when you exit the shell.
 func (root *Root) suspend() {
@@ -538,17 +553,21 @@ func jumpPosition(height int, str string) (int, bool) {
 	if len(s) > 0 && s[0] == 's' {
 		return 0, true
 	}
-	num := int(math.Round(docPosition(height, s)))
+	num := int(math.Round(calculatePosition(height, s)))
 	if num < 0 {
 		return (height - 1) + num, false
 	}
 	return num, false
 }
 
-// docPosition returns the number of lines from the top for positive
-// numbers (1), dot.number for percentages (.5) = 50%, and % after
-// the number for percentages (50%).
-func docPosition(height int, str string) float64 {
+// CalculatePosition returns the number from the length for positive
+// numbers (1), returns dot.number for percentages (.5) = 50%,
+// and returns the % after the number for percentages (50%). return.
+func calculatePosition(length int, str string) float64 {
+	if len(str) == 0 || str == "0" {
+		return 0
+	}
+
 	var p float64 = 0
 	if strings.HasPrefix(str, ".") {
 		str = strings.TrimLeft(str, ".")
@@ -568,15 +587,13 @@ func docPosition(height int, str string) float64 {
 	}
 
 	if p != 0 {
-		return float64(height) * p
+		return float64(length) * p
 	}
 
 	num, err := strconv.ParseFloat(str, 64)
 	if err != nil {
-		log.Println(err)
 		return 0
 	}
-
 	return num
 }
 
