@@ -87,8 +87,6 @@ type Document struct {
 	// columnCursor is the number of columns.
 	columnCursor int
 
-	// sectionHeaderNum is the number of lines in the section header.
-	sectionHeaderNum int
 	// jumpTargetNum is the display position of search results.
 	jumpTargetNum int
 	// jumpTargetSection is the display position of search results.
@@ -115,6 +113,8 @@ type Document struct {
 	seekable bool
 	// Is it possible to reopen.
 	reopenable bool
+	// startTopFlag
+	startTopFlag bool
 }
 
 // store represents store management.
@@ -173,11 +173,12 @@ func NewDocument() (*Document, error) {
 			TabWidth:        8,
 			MarkStyleWidth:  1,
 		},
-		ctlCh:       make(chan controlSpecifier),
-		memoryLimit: 100,
-		seekable:    true,
-		reopenable:  true,
-		store:       NewStore(),
+		ctlCh:        make(chan controlSpecifier),
+		memoryLimit:  100,
+		seekable:     true,
+		reopenable:   true,
+		store:        NewStore(),
+		startTopFlag: true,
 	}
 	if err := m.NewCache(); err != nil {
 		return nil, err
@@ -458,10 +459,6 @@ func (m *Document) setDelimiter(delm string) {
 func (m *Document) setSectionDelimiter(delm string) {
 	m.SectionDelimiter = delm
 	m.SectionDelimiterReg = regexpCompile(delm, true)
-	m.sectionHeaderNum = 0
-	if m.SectionHeader && m.SectionDelimiter != "" {
-		m.sectionHeaderNum = 1
-	}
 }
 
 // setMultiColorWords set multiple strings to highlight with multiple colors.
