@@ -38,11 +38,12 @@ func (root *Root) draw() {
 
 	// Section header
 	n := root.drawSectionHeader(lN)
-	if lN != n {
+	if m.startTopFlag && lN < m.SectionHeaderNum {
 		lN = n
-		m.topLN = lN
+		m.topLN = n
+	} else {
+		m.startTopFlag = false
 	}
-
 	// Body
 	lX, lN = root.drawBody(lX, lN)
 
@@ -110,6 +111,8 @@ func (root *Root) drawHeader() int {
 }
 
 // drawSectionHeader draws section header.
+// drawSectionHeader advances the line
+// if the section header contains a line in the terminal.
 func (root *Root) drawSectionHeader(lN int) int {
 	m := root.Doc
 	if !m.SectionHeader || m.SectionDelimiter == "" {
@@ -117,7 +120,8 @@ func (root *Root) drawSectionHeader(lN int) int {
 	}
 
 	pn := lN
-	if pn == 0 {
+	// prevSection searches for the section above the specified line.
+	if m.startTopFlag && pn <= 0 {
 		pn = 1
 	}
 	sectionLN, err := m.prevSection(pn)
@@ -134,7 +138,7 @@ func (root *Root) drawSectionHeader(lN int) int {
 	if pn > sectionLN {
 		sn = sectionLN
 		line, valid := m.getLineC(sn, m.TabWidth)
-		for y := m.headerLen; sn < sectionLN+m.sectionHeaderNum; y++ {
+		for y := m.headerLen; sn < sectionLN+m.SectionHeaderNum; y++ {
 			if root.Doc.LineNumMode {
 				if valid {
 					root.drawLineNumber(sn, y)
@@ -142,16 +146,22 @@ func (root *Root) drawSectionHeader(lN int) int {
 					root.blankLineNumber(y)
 				}
 			}
+			if valid {
+				root.styleContent(lN, line)
+			}
 			sx, nextN = root.drawLine(y, sx, sn, line.lc)
 			root.sectionLineHighlight(y, line.str)
 			m.headerLen += 1
 			if nextN != sn {
+				if root.scr.sectionHeaderLeft > 0 {
+					root.scr.sectionHeaderLeft--
+				}
 				sn = nextN
 				line, valid = m.getLineC(sn, m.TabWidth)
 			}
 		}
 	}
-	return pn
+	return pn + (m.SectionHeaderNum - 1)
 }
 
 // drawBody draws body.
@@ -187,6 +197,9 @@ func (root *Root) drawBody(lX int, lN int) (int, int) {
 		lX = nextX
 		if nextY != lN {
 			lN = nextY
+			if root.scr.sectionHeaderLeft > 0 {
+				root.scr.sectionHeaderLeft--
+			}
 			line, valid = m.getLineC(lN, m.TabWidth)
 			root.bodyStyle(line.lc, root.StyleBody)
 			if valid {
@@ -646,8 +659,11 @@ func (root *Root) sectionLineHighlight(y int, str string) {
 		log.Printf("Regular expression is not set: %s", root.Doc.SectionDelimiter)
 		return
 	}
-
-	if root.Doc.SectionDelimiterReg.MatchString(str) {
+	if root.scr.sectionHeaderLeft > 0 {
 		root.yStyle(y, root.StyleSectionLine)
 	}
+	if root.Doc.SectionDelimiterReg.MatchString(str) {
+		root.yStyle(y, root.StyleSectionLine)
+		root.scr.sectionHeaderLeft = root.Doc.SectionHeaderNum
+	}
 }
