@@ -1,12 +1,17 @@
 package oviewer
 
-import "github.com/gdamore/tcell/v2"
+import (
+	"github.com/gdamore/tcell/v2"
+)
 
 // setJumpTargetMode sets the inputMode to JumpTarget.
 func (root *Root) setJumpTargetMode() {
 	input := root.input
 	input.value = ""
 	input.cursorX = 0
+
+	input.JumpTargetCandidate.toLast(root.Doc.JumpTarget)
+
 	input.Event = newJumpTargetEvent(input.JumpTargetCandidate)
 }
 
@@ -44,8 +49,7 @@ func (e *eventJumpTarget) Prompt() string {
 // Confirm returns the event when the input is confirmed.
 func (e *eventJumpTarget) Confirm(str string) tcell.Event {
 	e.value = str
-	e.clist.list = toLast(e.clist.list, str)
-	e.clist.p = 0
+	e.clist.toLast(str)
 	e.SetEventNow()
 	return e
 }
