@@ -32,6 +32,8 @@ const (
 	actionMoveDown       = "down"
 	actionMoveUp         = "up"
 	actionMoveTop        = "top"
+	actionMoveWidthLeft  = "width_left"
+	actionMoveWidthRight = "width_right"
 	actionMoveLeft       = "left"
 	actionMoveRight      = "right"
 	actionMoveHfLeft     = "half_left"
@@ -66,6 +68,7 @@ const (
 	actionSkipLines      = "skip_lines"
 	actionTabWidth       = "tabwidth"
 	actionGoLine         = "goto"
+	actionSectionNum     = "section_header_num"
 	actionNextSearch     = "next_search"
 	actionNextBackSearch = "next_backsearch"
 	actionNextDoc        = "next_doc"
@@ -114,6 +117,8 @@ func (root *Root) handlers() map[string]func() {
 		actionMovePgDn:       root.movePgDn,
 		actionMoveHfUp:       root.moveHfUp,
 		actionMoveHfDn:       root.moveHfDn,
+		actionMoveWidthLeft:  root.moveWidthLeft,
+		actionMoveWidthRight: root.moveWidthRight,
 		actionMoveLeft:       root.moveLeftOne,
 		actionMoveRight:      root.moveRightOne,
 		actionMoveHfLeft:     root.moveHfLeft,
@@ -143,6 +148,7 @@ func (root *Root) handlers() map[string]func() {
 		actionSkipLines:      root.setSkipLinesMode,
 		actionTabWidth:       root.setTabWidthMode,
 		actionGoLine:         root.setGoLineMode,
+		actionSectionNum:     root.setSectionNumMode,
 		actionNextSearch:     root.sendNextSearch,
 		actionNextBackSearch: root.sendNextBackSearch,
 		actionNextDoc:        root.nextDoc,
@@ -194,6 +200,8 @@ func defaultKeyBinds() KeyBind {
 		actionMovePgDn:       {"PageDown", "ctrl+v"},
 		actionMoveHfUp:       {"ctrl+u"},
 		actionMoveHfDn:       {"ctrl+d"},
+		actionMoveWidthLeft:  {"ctrl+shift+left"},
+		actionMoveWidthRight: {"ctrl+shift+right"},
 		actionMoveLeft:       {"left"},
 		actionMoveRight:      {"right"},
 		actionMoveHfLeft:     {"ctrl+left"},
@@ -223,6 +231,7 @@ func defaultKeyBinds() KeyBind {
 		actionSkipLines:      {"ctrl+s"},
 		actionTabWidth:       {"t"},
 		actionGoLine:         {"g"},
+		actionSectionNum:     {"F7"},
 		actionNextSearch:     {"n"},
 		actionNextBackSearch: {"N"},
 		actionNextDoc:        {"]"},
@@ -248,8 +257,7 @@ func defaultKeyBinds() KeyBind {
 // String returns keybind as a string for help.
 func (k KeyBind) String() string {
 	var b strings.Builder
-	fmt.Fprint(&b, "\n\tKey binding\n")
-	fmt.Fprint(&b, "\n")
+	writeHeader(&b, "Key binding")
 	k.writeKeyBind(&b, actionExit, "quit")
 	k.writeKeyBind(&b, actionCancel, "cancel")
 	k.writeKeyBind(&b, actionWriteExit, "output screen and quit")
@@ -263,8 +271,7 @@ func (k KeyBind) String() string {
 	k.writeKeyBind(&b, actionToggleMouse, "enable/disable mouse")
 	k.writeKeyBind(&b, actionSaveBuffer, "save buffer to file")
 
-	fmt.Fprint(&b, "\n\tMoving\n")
-	fmt.Fprint(&b, "\n")
+	writeHeader(&b, "Moving")
 	k.writeKeyBind(&b, actionMoveDown, "forward by one line")
 	k.writeKeyBind(&b, actionMoveUp, "backward by one line")
 	k.writeKeyBind(&b, actionMoveTop, "go to top of document")
@@ -277,33 +284,31 @@ func (k KeyBind) String() string {
 	k.writeKeyBind(&b, actionMoveRight, "scroll to right")
 	k.writeKeyBind(&b, actionMoveHfLeft, "scroll left half screen")
 	k.writeKeyBind(&b, actionMoveHfRight, "scroll right half screen")
+	k.writeKeyBind(&b, actionMoveWidthLeft, "scroll left specified width")
+	k.writeKeyBind(&b, actionMoveWidthRight, "scroll right specified width")
 	k.writeKeyBind(&b, actionMoveBeginLeft, "go to beginning of line")
 	k.writeKeyBind(&b, actionMoveEndRight, "go to end of line")
 	k.writeKeyBind(&b, actionGoLine, "go to line(input number or `.n` or `n%` allowed)")
 
-	fmt.Fprint(&b, "\n\tMove document\n")
-	fmt.Fprint(&b, "\n")
+	writeHeader(&b, "Move document")
 	k.writeKeyBind(&b, actionNextDoc, "next document")
 	k.writeKeyBind(&b, actionPreviousDoc, "previous document")
 	k.writeKeyBind(&b, actionCloseDoc, "close current document")
 
-	fmt.Fprint(&b, "\n\tMark position\n")
-	fmt.Fprint(&b, "\n")
+	writeHeader(&b, "Mark position")
 	k.writeKeyBind(&b, actionMark, "mark current position")
 	k.writeKeyBind(&b, actionRemoveMark, "remove mark current position")
 	k.writeKeyBind(&b, actionRemoveAllMark, "remove all mark")
 	k.writeKeyBind(&b, actionMoveMark, "move to next marked position")
 	k.writeKeyBind(&b, actionMovePrevMark, "move to previous marked position")
 
-	fmt.Fprint(&b, "\n\tSearch\n")
-	fmt.Fprint(&b, "\n")
+	writeHeader(&b, "Search")
 	k.writeKeyBind(&b, actionSearch, "forward search mode")
 	k.writeKeyBind(&b, actionBackSearch, "backward search mode")
 	k.writeKeyBind(&b, actionNextSearch, "repeat forward search")
 	k.writeKeyBind(&b, actionNextBackSearch, "repeat backward search")
 
-	fmt.Fprint(&b, "\n\tChange display\n")
-	fmt.Fprint(&b, "\n")
+	writeHeader(&b, "Change display")
 	k.writeKeyBind(&b, actionWrap, "wrap/nowrap toggle")
 	k.writeKeyBind(&b, actionColumnMode, "column mode toggle")
 	k.writeKeyBind(&b, actionColumnWidth, "column width toggle")
@@ -312,8 +317,7 @@ func (k KeyBind) String() string {
 	k.writeKeyBind(&b, actionLineNumMode, "line number toggle")
 	k.writeKeyBind(&b, actionPlain, "original decoration toggle(plain)")
 
-	fmt.Fprint(&b, "\n\tChange Display with Input\n")
-	fmt.Fprint(&b, "\n")
+	writeHeader(&b, "Change Display with Input")
 	k.writeKeyBind(&b, actionViewMode, "view mode selection")
 	k.writeKeyBind(&b, actionDelimiter, "column delimiter string")
 	k.writeKeyBind(&b, actionHeader, "number of header lines")
@@ -322,24 +326,22 @@ func (k KeyBind) String() string {
 	k.writeKeyBind(&b, actionMultiColor, "multi color highlight")
 	k.writeKeyBind(&b, actionJumpTarget, "jump target(`.n` or `n%` or `section` allowed)")
 
-	fmt.Fprint(&b, "\n\tSection\n")
-	fmt.Fprint(&b, "\n")
+	writeHeader(&b, "Section")
 	k.writeKeyBind(&b, actionSection, "section delimiter regular expression")
 	k.writeKeyBind(&b, actionSectionStart, "section start position")
 	k.writeKeyBind(&b, actionNextSection, "next section")
 	k.writeKeyBind(&b, actionPrevSection, "previous section")
 	k.writeKeyBind(&b, actionLastSection, "last section")
 	k.writeKeyBind(&b, actionFollowSection, "follow section mode toggle")
+	k.writeKeyBind(&b, actionSectionNum, "section header number")
 
-	fmt.Fprint(&b, "\n\tClose and reload\n")
-	fmt.Fprint(&b, "\n")
+	writeHeader(&b, "Close and reload")
 	k.writeKeyBind(&b, actionCloseFile, "close file")
 	k.writeKeyBind(&b, actionReload, "reload file")
 	k.writeKeyBind(&b, actionWatch, "watch mode")
 	k.writeKeyBind(&b, actionWatchInterval, "set watch interval")
 
-	fmt.Fprint(&b, "\n\tKey binding when typing\n")
-	fmt.Fprint(&b, "\n")
+	writeHeader(&b, "Key binding when typing")
 	k.writeKeyBind(&b, inputCaseSensitive, "case-sensitive toggle")
 	k.writeKeyBind(&b, inputSmartCaseSensitive, "smart case-sensitive toggle")
 	k.writeKeyBind(&b, inputRegexpSearch, "regular expression search toggle")
@@ -351,6 +353,10 @@ func (k KeyBind) String() string {
 	return b.String()
 }
 
+func writeHeader(w io.Writer, header string) {
+	fmt.Fprintf(w, "\n\t%s\n", header)
+}
+
 func (k KeyBind) writeKeyBind(w io.Writer, action string, detail string) {
 	fmt.Fprintf(w, " %-28s * %s\n", "["+strings.Join(k[action], "], [")+"]", detail)
 }
