@@ -6,6 +6,7 @@ import (
 	"fmt"
 	"io"
 	"log"
+	"math"
 	"os"
 	"os/signal"
 	"path/filepath"
@@ -93,6 +94,8 @@ type SCR struct {
 	vHeight int
 	// startX is the start position of x.
 	startX int
+	// Process as a section header if the remaining value is 1 or more.
+	sectionHeaderLeft int
 }
 
 // LineNumber is Number of logical lines and number of wrapping lines on the screen.
@@ -129,6 +132,12 @@ type general struct {
 	MarkStyleWidth int
 	// SectionStartPosition is a section start position.
 	SectionStartPosition int
+	// SectionHeaderNum is the number of lines in the section header.
+	SectionHeaderNum int
+	// HScrollWidth is the horizontal scroll width.
+	HScrollWidth string
+	// HScrollWidthNum is the horizontal scroll width.
+	HScrollWidthNum int
 	// AlternateRows alternately style rows.
 	AlternateRows bool
 	// ColumnMode is column mode.
@@ -866,6 +875,9 @@ func mergeGeneral(src general, dst general) general {
 	if dst.JumpTarget != "" {
 		src.JumpTarget = dst.JumpTarget
 	}
+	if dst.HScrollWidth != "" {
+		src.HScrollWidth = dst.HScrollWidth
+	}
 	if len(dst.MultiColorWords) > 0 {
 		src.MultiColorWords = dst.MultiColorWords
 	}
@@ -880,8 +892,13 @@ func (root *Root) prepareView() {
 	// Do not allow size 0.
 	root.scr.vWidth = max(root.scr.vWidth, 1)
 	root.scr.vHeight = max(root.scr.vHeight, 1)
-	root.scr.numbers = make([]LineNumber, root.scr.vHeight+1)
 	root.Doc.statusPos = root.scr.vHeight - statusLine
+
+	num := int(math.Round(calculatePosition(root.scr.vWidth, root.Doc.HScrollWidth)))
+	root.Doc.HScrollWidthNum = max(num, 1)
+	if len(root.scr.numbers) != root.scr.vHeight+1 {
+		root.scr.numbers = make([]LineNumber, root.scr.vHeight+1)
+	}
 }
 
 // docSmall returns with bool whether the file to display fits on the screen.
@@ -916,7 +933,7 @@ func (root *Root) WriteOriginal() {
 		m.bottomLN = m.BufEndNum()
 	}
 
-	start := max(0, m.topLN-(m.sectionHeaderNum+root.BeforeWriteOriginal))
+	start := max(0, m.topLN-(m.SectionHeaderNum+root.BeforeWriteOriginal))
 	end := m.bottomLN - 1
 	if root.AfterWriteOriginal != 0 {
 		end = m.topLN + root.AfterWriteOriginal - 1
