@@ -159,10 +159,10 @@ func (m *Document) loadChunk(reader *bufio.Reader, chunkNum int) (*bufio.Reader,
 
 	start, end := m.store.chunkRange(chunkNum)
 	if err := m.store.readLines(chunk, reader, start, end, false); err != nil {
-		log.Printf("Failed to read the expected number of lines(%d:%d): %s", start, end, err)
 		if errors.Is(err, io.EOF) {
 			return m.afterEOF(reader), nil
 		}
+		log.Printf("Failed to read the expected number of lines(%d:%d): %s", start, end, err)
 		return nil, err
 	}
 	return reader, nil
@@ -223,12 +223,14 @@ func (m *Document) loadReadMem(reader *bufio.Reader, chunkNum int) (*bufio.Reade
 
 // reloadRead performs reload processing.
 func (m *Document) reloadRead(reader *bufio.Reader) (*bufio.Reader, error) {
-	if !m.WatchMode {
-		m.reset()
-	} else {
+	// Add to store in WatchMode, otherwise reset
+	if m.WatchMode {
 		m.seekable = false
 		chunk := m.store.chunkForAdd(m.seekable, m.store.size)
 		m.store.appendFormFeed(chunk)
+	} else {
+		m.store.loadedChunks.Purge()
+		m.reset()
 	}
 
 	return m.reloadFile(reader)
@@ -264,6 +266,7 @@ func (m *Document) afterEOF(reader *bufio.Reader) *bufio.Reader {
 	m.store.offset = m.store.size
 	atomic.StoreInt32(&m.store.eof, 1)
 	if atomic.SwapInt32(&m.tmpFollow, 0) == 1 {
+		atomic.StoreInt32(&m.tmpLN, atomic.LoadInt32(&m.followStore.endNum))
 		m.cache.Purge()
 	}
 	if !m.seekable { // for NamedPipe.
@@ -273,7 +276,6 @@ func (m *Document) afterEOF(reader *bufio.Reader) *bufio.Reader {
 }
 
 // openFileReader opens a file,
-// selects a reader according to compression type and returns io.Reader.
 func (m *Document) openFileReader(fileName string) (io.Reader, error) {
 	f, err := open(fileName)
 	if err != nil {
@@ -283,13 +285,20 @@ func (m *Document) openFileReader(fileName string) (io.Reader, error) {
 }
 
 // fileReader returns a io.Reader.
+// selects a reader according to compression type and returns io.Reader.
 func (m *Document) fileReader(f *os.File) (io.Reader, error) {
 	m.store.mu.Lock()
 	defer m.store.mu.Unlock()
 
 	atomic.StoreInt32(&m.closed, 0)
 	m.file = f
-	cFormat, r := uncompressedReader(m.file, m.seekable)
+
+	cFormat := UNCOMPRESSED
+	r := io.Reader(m.file)
+	if !SkipExtract {
+		cFormat, r = uncompressedReader(m.file, m.seekable)
+	}
+
 	if cFormat == UNCOMPRESSED {
 		if m.seekable {
 			if _, err := f.Seek(0, io.SeekStart); err != nil {
@@ -351,8 +360,11 @@ func (m *Document) reload() error {
 
 // reset clears all lines.
 func (m *Document) reset() {
+	if !m.BufEOF() {
+		return
+	}
 	m.store = NewStore()
-	m.store.setNewLoadChunks(m.seekable)
+	m.store.setNewLoadChunks(m.memoryLimit)
 	atomic.StoreInt32(&m.store.changed, 1)
 	m.ClearCache()
 }
